OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalenteri",
    "Group" : "Ryhmä",
    "Resource" : "Resurssi",
    "Room" : "Huone",
    "Unknown" : "Tuntematon",
    "Required" : "Vaadittu",
    "Optional" : "Valinnainen",
    "Does not attend" : "Ei osallistu",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Olet tuntemattomalla aikavyöhykkeellä ({tz}), palataan UTC-tilaan",
    "Please create a calendar first." : "Luo ensin kalenteri.",
    "New event" : "Uusi tapahtuma",
    "Attendees" : "Osallistujat",
    "Reminders" : "Muistutukset",
    "Repeating" : "Toisto",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
    "Please add a title!" : "Lisää otsikko!",
    "Please select a calendar!" : "Valitse kalenteri!",
    "None" : "Ei mitään",
    "Every day" : "Päivittäin",
    "Every week" : "Viikottain",
    "Every month" : "Kuukausittain",
    "Every year" : "Vuosittain",
    "never" : "ei koskaan",
    "At time of event" : "Tapahtuman aikaan",
    "5 minutes before" : "5 minuuttia ennen",
    "10 minutes before" : "10 minuuttia ennen",
    "15 minutes before" : "15 minuuttia ennen",
    "30 minutes before" : "30 minuuttia ennen",
    "1 hour before" : "1 tunti ennen",
    "2 hours before" : "2 tuntia ennen",
    "Custom" : "Omavalintainen",
    "Audio" : "Ääni",
    "E Mail" : "Sähköposti",
    "Pop up" : "Ponnahdus",
    "sec" : "s",
    "min" : "min",
    "hours" : "tuntia",
    "days" : "päivää",
    "week" : "viikko",
    "Week {number} of {year}" : "Viikko {number} vuonna {year}",
    "Successfully imported" : "Tuotu onnistuneesti",
    "Partially imported, 1 failure" : "Tuotu osittain, 1 epäonnistui",
    "Partially imported, {n} failures" : "Tuotu osittain, {n} epäonnistui",
    "Audio alarm" : "Äänihälytys",
    "Pop-up" : "Ponnahdusikkuna",
    "E-Mail" : "Sähköposti",
    "{type} {time} before the event starts" : "{type} {time} ennen tapahtuman alkua",
    "{type} {time} before the event ends" : "{type} {time} ennen tapahtuman loppua",
    "{type} {time} after the event starts" : "{type} {time} tapahtuman alkamisen jälkeen",
    "{type} {time} after the event ends" : "{type} {time} tapahtuman päättymisen jälkeen",
    "{type} at the event's start" : "{type} tapahtuman alkaessa",
    "{type} at the event's end" : "{type} tapahtuman päättyessä",
    "{type} at {time}" : "{type} ajankohtana {time}",
    "{calendar} shared by {owner}" : "{calendar} jakanut {owner}",
    "Title of the Event" : "Tapahtuman otsikko",
    "starts" : "alkaa",
    "ends" : "päättyy",
    "All day Event" : "Koko päivän tapahtuma",
    "Location" : "Sijainti",
    "Delete" : "Poista",
    "Cancel" : "Peruuta",
    "More ..." : "Lisää...",
    "Create" : "Luo",
    "Update" : "Päivitä",
    "Close" : "Sulje",
    "Description" : "Kuvaus",
    "Export" : "Vie",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ota yhteys ylläpitoon ja pyydä poistamaan käytöstä valinta \"asset-pipeline.enabled\" asetustiedostosta.",
    "Day" : "Päivä",
    "Week" : "Viikko",
    "Month" : "Kuukausi",
    "Today" : "Tänään",
    "Share Calendar" : "Jaa kalenteri",
    "More" : "Lisää",
    "Edit" : "Muokkaa",
    "CalDAV" : "CalDAV",
    "group" : "ryhmä",
    "New Calendar" : "Uusi kalenteri",
    "Subscriptions" : "Tilaukset",
    "New Subscription" : "Uusi tilaus",
    "Url" : "Osoite",
    "Edit event" : "Muokkaa tapahtumaa",
    "Delete Event" : "Poista tapahtuma",
    "Save Event" : "Tallenna tapahtuma",
    "Time" : "Aika",
    "Type" : "Tyyppi",
    "Repeat" : "Kertaa",
    "Add" : "Lisää",
    "E-Mail address of attendee" : "Osallistujan sähköpostiosoite",
    "Please add your email address in the personal settings in order to add attendees." : "Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiin, jotta voit lisätä osallistujia.",
    "from" : "alkaen",
    "to" : "päättyen",
    "This event's repeating rule is not supported yet." : "Tämän tapahtuman toistuva sääntö ei ole vielä tuettu.",
    "Support for advanced rules will be added with subsequent updates." : "Tuki kehittyneille säännöille lisätään myöhemmin julkaistavissa päivityksissä.",
    "Reset repeating rule" : "Nollaa toistuva sääntö",
    "Import Calendars" : "Tuo kalentereita",
    "Import canceled" : "Tuonti peruttu",
    "Analyzing calendar" : "Analysoidaan kalenteria",
    "The file contains objects incompatible with the selected calendar" : "Tiedosto sisältää valitun kalenterin kanssa yhteensopimattomia objekteja",
    "New calendar" : "Uusi kalenteri",
    "Import scheduled" : "Tuonti ajastettu",
    "Settings" : "Asetukset",
    "Import calendar" : "Tuo kalenteri",
    "No Calendars selected for import" : "Kalentereita ei ole valittu tuotavaksi",
    "Primary CalDAV address" : "Ensisijainen CalDAV-osoite",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV -osoite"
},
"nplurals=2; plural=(n != 1);");
